from bluer_options.logger.config import (
    logger,
    crash_report,
    get_logger,
    log_dict,
    log_list,
    log_list_as_str,
    log_long_text,
    shorten_text,
)
